==> cyanlib-1.0.9%2B1.20-1.20.1-sources.jar: fr/aeldit/cyanlib/lib/CyanLib.java <==
package fr.aeldit.cyanlib.lib;

import fr.aeldit.cyanlib.lib.config.CyanLibOptionsStorage;
import fr.aeldit.cyanlib.lib.config.ICyanLibConfig;
import org.jetbrains.annotations.NotNull;

import java.util.HashMap;
import java.util.Map;
import net.minecraft.class_3222;

import static fr.aeldit.cyanlib.core.CyanLibCore.CYANLIB_MOD_ID;

// TODO -> Add multi world support
public class CyanLib
{
    private final CyanLibOptionsStorage optionsStorage;
    private final CyanLibLanguageUtils languageUtils;
    // This Map stores the CyanLib instance of each mod using this library, the key in the map being the modId
    // of the mod
    public static final Map<String, CyanLib> CONFIG_CLASS_INSTANCES = new HashMap<>();

    /**
     * Main class of this library
     *
     * @param modId             The modId of your mod
     * @param cyanLibConfigImpl The {@link ICyanLibConfig} implementation
     */
    public CyanLib(String modId, ICyanLibConfig cyanLibConfigImpl)
    {
        this.optionsStorage = new CyanLibOptionsStorage(modId, cyanLibConfigImpl);
        this.languageUtils = new CyanLibLanguageUtils(modId);

        CONFIG_CLASS_INSTANCES.put(modId, this);
        languageUtils.loadCustomLanguage(this.optionsStorage.getConfigClass().getDefaultTranslations());
    }

    public CyanLibOptionsStorage getOptionsStorage()
    {
        return optionsStorage;
    }

    public CyanLibLanguageUtils getLanguageUtils()
    {
        return languageUtils;
    }

    /**
     * Returns whether the player has the required OP level or not, and sends a message if this condition is
     * {@code false}
     *
     * @param player     the player
     * @param permission the OP level ({@code 0 <= permission <= 4})
     */
    public boolean hasPermission(@NotNull class_3222 player, int permission)
    {
        if (!player.method_5687(permission))
        {
            languageUtils.sendPlayerMessageMod(player, CYANLIB_MOD_ID, "error.notOp");
            return false;
        }
        return true;
    }

    /**
     * Returns whether the player the option is allowed or not, and sends a message if this condition is {@code false}
     *
     * @param player         the player
     * @param option         the option you want to test
     * @param translationKey the path to the translation (in the method, the translations path is {@code "mod_id.message
     *                       .OPTION"},
     *                       where {@code mod_id} is the modId of your mod and {@code OPTION} is the {@code
     *                       translationKey})
     */
    @SuppressWarnings("unused")
    public boolean isOptionEnabled(class_3222 player, boolean option, String translationKey)
    {
        if (!option)
        {
            languageUtils.sendPlayerMessage(player, "error.%s".formatted(translationKey));
        }
        return option;
    }
}

==> cyanlib-1.0.11%2B1.21.6-1.21.8-sources.jar: fr/aeldit/cyanlib/lib/CyanLib.java <==
package fr.aeldit.cyanlib.lib;

import fr.aeldit.cyanlib.lib.config.CyanLibOptionsStorage;
import fr.aeldit.cyanlib.lib.config.ICyanLibConfig;
import org.jetbrains.annotations.NotNull;

import java.util.HashMap;
import java.util.Map;
import net.minecraft.class_3222;

import static fr.aeldit.cyanlib.core.CyanLibCore.CYANLIB_MOD_ID;

// TODO -> Add multi world support
public class CyanLib
{
    public final CyanLibOptionsStorage optionsStorage;
    public final CyanLibLanguageUtils languageUtils;
    // This Map stores the CyanLib instance of each mod using this library, the key in the map being the modId
    // of the mod
    public static final Map<String, CyanLib> CONFIG_CLASS_INSTANCES = new HashMap<>();

    /**
     * Main class of this library
     *
     * @param modId             The modId of your mod
     * @param cyanLibConfigImpl The {@link ICyanLibConfig} implementation
     */
    public CyanLib(String modId, ICyanLibConfig cyanLibConfigImpl)
    {
        this.optionsStorage = new CyanLibOptionsStorage(modId, cyanLibConfigImpl);
        this.languageUtils = new CyanLibLanguageUtils(modId);

        CONFIG_CLASS_INSTANCES.put(modId, this);
        languageUtils.loadCustomLanguage(this.optionsStorage.configClass.getDefaultTranslations());
    }

    /**
     * Returns whether the player has the required OP level or not, and sends a message if this condition is
     * {@code false}
     *
     * @param player     the player
     * @param permission the OP level ({@code 0 <= permission <= 4})
     */
    public boolean hasPermission(@NotNull class_3222 player, int permission)
    {
        //? if >= 1.21.11 {
        /*if (!player.getPermissions().hasPermission(new Permission.Level(PermissionLevel.fromLevel(permission))))
            *///?} else {
            if (!player.method_64475(permission))
             //?}
        {
            languageUtils.sendPlayerMessageMod(player, CYANLIB_MOD_ID, "error.notOp");
            return false;
        }
        return true;
    }

    /**
     * Returns whether the player the option is allowed or not, and sends a message if this condition is {@code false}
     *
     * @param player         the player
     * @param option         the option you want to test
     * @param translationKey the path to the translation (in the method, the translations path is {@code "mod_id.message
     *                       .OPTION"},
     *                       where {@code mod_id} is the modId of your mod and {@code OPTION} is the {@code
     *                       translationKey})
     */
    @SuppressWarnings("unused")
    public boolean isOptionEnabled(class_3222 player, boolean option, String translationKey)
    {
        if (!option)
        {
            languageUtils.sendPlayerMessage(player, "error.%s".formatted(translationKey));
        }
        return option;
    }
}
